@@ -1,7 +1,7 @@
 /**********
 This library is free software; you can redistribute it and/or modify it under
 the terms of the GNU Lesser General Public License as published by the
-Free Software Foundation; either version 2.1 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)
 
 This library is distributed in the hope that it will be useful, but WITHOUT
@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2013 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2017 Live Networks, Inc.  All rights reserved.
 // Bit Vector data structure
 // Implementation
 
@@ -136,9 +136,18 @@ unsigned BitVector::get_expGolomb() {
     codeStart *= 2;
   }
 
-  return codeStart -1 + getBits(numLeadingZeroBits);
+  return codeStart - 1 + getBits(numLeadingZeroBits);
 }
 
+int BitVector::get_expGolombSigned() {
+  unsigned codeNum = get_expGolomb();
+
+  if ((codeNum&1) == 0) { // even
+    return -(codeNum/2);
+  } else { // odd
+    return (codeNum+1)/2;
+  }
+}
 
 void shiftBits(unsigned char* toBasePtr, unsigned toBitOffset,
 	       unsigned char const* fromBasePtr, unsigned fromBitOffset,
